@@ -5,6 +5,7 @@
 #' @param ... additional parameters passed to \code{data.table::rbindlist}.
 #' @param data.table \code{TRUE} to keep the result as \code{data.table}
 #' @export
+#' @importFrom data.table rbindlist
 #' @examples
 #' \dontrun{
 #' x <- lapply(1:3, function(i) { list(a=i,b=i^2) })
@@ -20,9 +21,8 @@
 #' list.stack(x)
 #' }
 list.stack <- function(.data, ..., data.table = FALSE) {
-  if (!requireNamespace("data.table", quietly = TRUE))
-    stop("data.table is needed for this function to work. Please install it.", call. = FALSE)
   dt <- data.table::rbindlist(.data, ...)
-  if(!data.table) data.table::setDF(dt)
+  if (!data.table)
+    data.table::setDF(dt)
   dt
 }
